@@ -20,6 +20,7 @@
 
 #include <QStandardPaths>
 #include "byteorder.h"
+#include "auxiliary/kspaths.h"
 
 class BinFileHelper;
 
@@ -53,7 +54,7 @@ void BinFileHelper::clearFields() {
 }
 
 bool BinFileHelper::testFileExists( const QString &fileName ) {
-    QString FilePath = QStandardPaths::locate(QStandardPaths::DataLocation, fileName );
+    QString FilePath = KSPaths::locate(QStandardPaths::GenericDataLocation, fileName );
     QByteArray b = FilePath.toLatin1();
     const char *filepath = b.data();
     FILE *f  = fopen(filepath, "rb");
@@ -66,7 +67,7 @@ bool BinFileHelper::testFileExists( const QString &fileName ) {
 }
 
 FILE *BinFileHelper::openFile(const QString &fileName) {
-    QString FilePath = QStandardPaths::locate(QStandardPaths::DataLocation, fileName );
+    QString FilePath = KSPaths::locate(QStandardPaths::GenericDataLocation, fileName );
     init();
     QByteArray b = FilePath.toLatin1();
     const char *filepath = b.data();
@@ -81,8 +82,7 @@ FILE *BinFileHelper::openFile(const QString &fileName) {
 }
 
 enum BinFileHelper::Errors BinFileHelper::__readHeader() {
-    int i;
-    qint16 endian_id;
+    qint16 endian_id, i;
     char ASCII_text[125];
     dataElement *de;
 
@@ -110,9 +110,12 @@ enum BinFileHelper::Errors BinFileHelper::__readHeader() {
     if( byteswap ) nfields = bswap_16( nfields );
     fields.clear();
     for(i = 0; i < nfields; ++i) {
+        // FIXME: Valgrind shows 176 bytes lost here in 11 blocks. Why? Investigate
         de = new dataElement;
-        if(!fread(de, sizeof(dataElement), 1, fileHandle)) {
+        if(!fread(de, sizeof(dataElement), 1, fileHandle))
+        {
             delete de;
+            qDeleteAll(fields);
             return ERR_FD_TRUNC;
         }
         if( byteswap ) de->scale = bswap_32( de->scale );
@@ -131,7 +134,8 @@ enum BinFileHelper::Errors BinFileHelper::__readHeader() {
     // Read the index table
     fread(&indexSize, 4, 1, fileHandle);
     if( byteswap ) indexSize = bswap_32( indexSize );
-    
+
+    quint32 j;
     quint32 ID;
     quint32 offset;
     quint32 prev_offset;
@@ -151,9 +155,9 @@ enum BinFileHelper::Errors BinFileHelper::__readHeader() {
         errorMessage.sprintf( "Zero index size!" );
         return ERR_INDEX_TRUNC;
     }
-    for(i = 0; i < indexSize; ++i) {
+    for(j = 0; j < indexSize; ++j) {
         if(!fread(&ID, 4, 1, fileHandle)) {
-            errorMessage.sprintf("Table truncated before expected! Read i = %d index entries so far", i);
+            errorMessage.sprintf("Table truncated before expected! Read i = %d index entries so far", j);
             return ERR_INDEX_TRUNC;
         }
         if( byteswap ) ID = bswap_32( ID );
@@ -161,23 +165,23 @@ enum BinFileHelper::Errors BinFileHelper::__readHeader() {
             errorMessage.sprintf("ID %u is greater than the expected number of expected entries (%u)", ID, indexSize);
             return ERR_INDEX_BADID;
         }
-        if(ID != i) {
-            errorMessage.sprintf("Found ID %u, at the location where ID %u was expected", ID, i);
+        if(ID != j) {
+            errorMessage.sprintf("Found ID %u, at the location where ID %u was expected", ID, j);
             return ERR_INDEX_IDMISMATCH;
         }
         if(!fread(&offset, 4, 1, fileHandle)) {
-            errorMessage.sprintf("Table truncated before expected! Read i = %d index entries so far", i);
+            errorMessage.sprintf("Table truncated before expected! Read i = %d index entries so far", j);
             return ERR_BADSEEK;
         }
         if( byteswap ) offset = bswap_32( offset );
         if(!fread(&nrecs, 4, 1, fileHandle)) {
-            errorMessage.sprintf("Table truncated before expected! Read i = %d index entries so far", i);
+            errorMessage.sprintf("Table truncated before expected! Read i = %d index entries so far", j);
             return ERR_BADSEEK;
         }
         if( byteswap ) nrecs = bswap_32( nrecs );
         if(prev_offset != 0 && prev_nrecs != (-prev_offset + offset)/recordSize) { 
             errorMessage.sprintf("Expected %u  = (%X - %x) / %x records, but found %u, in index entry %u", 
-                                    (offset - prev_offset) / recordSize, offset, prev_offset, recordSize, prev_nrecs, i - 1);
+                                    (offset - prev_offset) / recordSize, offset, prev_offset, recordSize, prev_nrecs, j - 1);
             return ERR_INDEX_BADOFFSET;
         }
 
