@@ -108,7 +108,7 @@ bool FITSTab::loadFITS(const QUrl *imageURL, FITSMode mode, FITSScale filter, bo
 
     view->setFilter(filter);
 
-    bool imageLoad = view->loadFITS(imageURL->url(), silent);
+    bool imageLoad = view->loadFITS(imageURL->toLocalFile(), silent);
 
     if (imageLoad)
     {
@@ -131,7 +131,6 @@ bool FITSTab::loadFITS(const QUrl *imageURL, FITSMode mode, FITSScale filter, bo
         view->updateFrame();
     }
 
-
     return imageLoad;
 }
 
@@ -250,7 +249,7 @@ bool FITSTab::saveFile()
     QUrl currentDir(Options::fitsDir());
     currentDir.setScheme("file");
 
-    if (currentURL.path().contains("/tmp/"))
+    if (currentURL.toLocalFile().startsWith("/tmp/") || currentURL.toLocalFile().contains("/Temp"))
         currentURL.clear();
 
     // If no changes made, return.
@@ -267,10 +266,10 @@ bool FITSTab::saveFile()
             return false;
         }
 
-        if (currentURL.path().contains('.') == 0)
-            currentURL.setPath(currentURL.path() + ".fits");
+        if (currentURL.toLocalFile().contains('.') == 0)
+            currentURL.setPath(currentURL.toLocalFile() + ".fits");
 
-        if (QFile::exists(currentURL.path()))
+        if (QFile::exists(currentURL.toLocalFile()))
         {
             int r = KMessageBox::warningContinueCancel(0,
                         i18n( "A file named \"%1\" already exists. "
@@ -285,7 +284,7 @@ bool FITSTab::saveFile()
 
     if ( currentURL.isValid() )
     {
-        if ( (err_status = saveFITS('!' + currentURL.path())) != 0)
+        if ( (err_status = saveFITS('!' + currentURL.toLocalFile())) != 0)
         {
             // -1000 = user canceled
             if (err_status == -1000)
@@ -319,23 +318,28 @@ bool FITSTab::saveFileAs()
 
 void FITSTab::ZoomIn()
 {
-   view->ZoomIn();
+    QPoint oldCenter=view->getImagePoint(view->viewport()->rect().center());
+    view->ZoomIn();
+    view->cleanUpZoom(oldCenter);
 }
 
 void FITSTab::ZoomOut()
 {
-  view->ZoomOut();
+    QPoint oldCenter=view->getImagePoint(view->viewport()->rect().center());
+    view->ZoomOut();
+    view->cleanUpZoom(oldCenter);
 }
 
 void FITSTab::ZoomDefault()
 {
-  view->ZoomDefault();
+    QPoint oldCenter=view->getImagePoint(view->viewport()->rect().center());
+    view->ZoomDefault();
+    view->cleanUpZoom(oldCenter);
 }
 
 void FITSTab::tabPositionUpdated()
 {
     undoStack->setActive(true);
-    emit newStatus(QString("%1").arg(view->getGammaValue()), FITS_GAMMA);
     emit newStatus(QString("%1%").arg(view->getCurrentZoom()), FITS_ZOOM);
     emit newStatus(QString("%1x%2").arg(view->getImageData()->getWidth()).arg(view->getImageData()->getHeight()), FITS_RESOLUTION);
 }
