@@ -35,15 +35,7 @@ const int MAX_FILENAME_LEN = 1024;
 namespace ISD
 {
 
-#ifdef INDI_VERSION_MAJOR
-#if (INDI_VERSION_MAJOR >= 1 && INDI_VERSION_MINOR >= 1)
 GDSetCommand::GDSetCommand(INDI_PROPERTY_TYPE inPropertyType, const QString &inProperty, const QString &inElement, QVariant qValue, QObject *parent) : QObject(parent)
-#else
-GDSetCommand::GDSetCommand(INDI_TYPE inPropertyType, const QString &inProperty, const QString &inElement, QVariant qValue, QObject *parent) : QObject(parent)
-#endif
-#else
-GDSetCommand::GDSetCommand(INDI_TYPE inPropertyType, const QString &inProperty, const QString &inElement, QVariant qValue, QObject *parent) : QObject(parent)
-#endif
 {
     propType     = inPropertyType;
     indiProperty = inProperty;
@@ -135,8 +127,9 @@ void GenericDevice::registerProperty(INDI::Property *prop)
 
             if (connected && nvp->np[0].value > 0)
             {
-                // Reset timer 15 seconds before it is due
-                watchDogTimer->start(nvp->np[0].value*60*1000 - 15*1000);
+                // Send immediately a heart beat
+                clientManager->sendNewNumber(nvp);
+                //watchDogTimer->start(0);
             }
         }
     }
@@ -167,8 +160,9 @@ void GenericDevice::processSwitch(ISwitchVectorProperty * svp)
                 INumberVectorProperty *nvp = baseDevice->getNumber("WATCHDOG_HEARTBEAT");
                 if (nvp && nvp->np[0].value > 0)
                 {
-                    // Reset timer 15 seconds before it is due
-                    watchDogTimer->start(nvp->np[0].value*60*1000 - 15*1000);
+                    // Send immediately
+                    clientManager->sendNewNumber(nvp);
+                    //watchDogTimer->start(0);
                 }
             }
         }
@@ -648,11 +642,8 @@ void GenericDevice::resetWatchdog()
     INumberVectorProperty *nvp = baseDevice->getNumber("WATCHDOG_HEARTBEAT");
 
     if (nvp)
-    {
-        // Reset timer 15 seconds before it is due
-        watchDogTimer->start(nvp->np[0].value*60*1000 - 15*1000);
-        clientManager->sendNewNumber(nvp);
-    }
+       // Send heartbeat to driver
+       clientManager->sendNewNumber(nvp);
 }
 
 DeviceDecorator::DeviceDecorator(GDInterface *iPtr)
