@@ -58,6 +58,7 @@ class PrintingWizard;
 class EkosManager;
 class HorizonManager;
 class EyepieceField;
+class AddDeepSkyObject;
 
 class OpsCatalog;
 class OpsGuides;
@@ -469,6 +470,9 @@ public Q_SLOTS:
     /** Show the eyepiece view tool */
     void slotEyepieceView( SkyPoint *sp, const QString &imagePath = QString() );
 
+    /** Show the add deep-sky object dialog */
+    void slotAddDeepSkyObject();
+
 
 private slots:
     /** action slot: open a dialog for setting the time and date */
@@ -676,13 +680,15 @@ private:
     HorizonManager *m_HorizonManager;
     EyepieceField *m_EyepieceView;
     #ifdef HAVE_CFITSIO
-    QPointer<FITSViewer> genericViewer;
+    QPointer<FITSViewer> m_GenericFITSViewer;
     #endif
 
     #ifdef HAVE_INDI
-    EkosManager *m_EkosManager;
+    QPointer<EkosManager> m_EkosManager;
     #endif
 
+    AddDeepSkyObject *m_addDSODialog;
+
     // FIXME Port to QML2
     //#if 0
     WIView *m_WIView;
