@@ -36,7 +36,9 @@
 #include "fov.h"
 #include "kstars.h"
 #include "kstarsdata.h"
+#include "kspaths.h"
 #include "skymap.h"
+#include "projections/projector.h"
 #include "skyobjects/skyobject.h"
 #include "skyobjects/ksplanetbase.h"
 #include "simclock.h"
@@ -131,50 +133,63 @@ namespace {
 
 void KStars::initActions() {
     //KIconLoader::global()->addAppDir( "kstars" );
+    
+    //This will check if there is an icon for a very common action to see if a theme is loaded.
+    //If one is not detected, it tries to set the theme to the one specified here.
+    static const char * GENERIC_ICON_TO_CHECK = "document-open";
+    static const char * ICON_THEME = "breeze";
+    if (!QIcon::hasThemeIcon(GENERIC_ICON_TO_CHECK)) {
+        QIcon::setThemeName(ICON_THEME);
+    }
+    
+    
     QAction *ka;
 
     // ==== File menu ================
     ka = KNS3::standardAction(i18n("Download New Data..."), this, SLOT(slotDownload()), actionCollection(), "get_data")
         << QKeySequence( Qt::CTRL+Qt::Key_N );
+    ka ->setIcon(QIcon::fromTheme("favorites" , QIcon(":/icons/breeze/default/favorites.svg")));
     ka->setWhatsThis(i18n("Downloads new data"));
     ka->setToolTip(ka->whatsThis());
     ka->setStatusTip(ka->whatsThis());
 
+    
 #ifdef HAVE_CFITSIO
     actionCollection()->addAction("open_file", this, SLOT(slotOpenFITS()) )
         << i18n("Open FITS...")
-        << QIcon::fromTheme("document-open")
+        << QIcon::fromTheme("document-open", QIcon(":/icons/breeze/default/document-open.svg"))
         << QKeySequence( Qt::CTRL+Qt::Key_O );
 #endif
-
     actionCollection()->addAction("export_image", this, SLOT( slotExportImage() ) )
         << i18n("&Save Sky Image...")
-        << QIcon::fromTheme("document-export-image")
+        << QIcon::fromTheme("document-export-image", QIcon(":/icons/breeze/default/document-export.svg"))
         << QKeySequence( Qt::CTRL+Qt::Key_I );
     actionCollection()->addAction("run_script", this, SLOT( slotRunScript() ))
         << i18n("&Run Script...")
-        << QIcon::fromTheme("system-run" )
+        << QIcon::fromTheme("system-run", QIcon(":/icons/breeze/default/system-run.svg"))
         << QKeySequence( Qt::CTRL+Qt::Key_R );
     actionCollection()->addAction("printing_wizard", this, SLOT(slotPrintingWizard() ) )
             << i18nc("start Printing Wizard", "Printing &Wizard");
-    actionCollection()->addAction( KStandardAction::Print, "print", this, SLOT( slotPrint() ) );
+    ka = actionCollection()->addAction( KStandardAction::Print, "print", this, SLOT( slotPrint() ) );
+    ka->setIcon( QIcon::fromTheme("document-print", QIcon(":/icons/breeze/default/document-print.svg")));
     //actionCollection()->addAction( KStandardAction::Quit,  "quit",  this, SLOT(close) );
-    actionCollection()->addAction( KStandardAction::Quit,  "quit",  qApp, SLOT(closeAllWindows()));
+    ka = actionCollection()->addAction( KStandardAction::Quit,  "quit",  qApp, SLOT(closeAllWindows()));
+    ka->setIcon( QIcon::fromTheme("application-exit", QIcon(":/icons/breeze/default/application-exit.svg")));
 
     // ==== Time Menu ================
     actionCollection()->addAction("time_to_now", this, SLOT( slotSetTimeToNow() ))
         << i18n("Set Time to &Now")
         << QKeySequence( Qt::CTRL+Qt::Key_E )
-        << QIcon::fromTheme("clock");
+        << QIcon::fromTheme("clock", QIcon(":/icons/breeze/default/clock.svg"));
 
     actionCollection()->addAction("time_dialog", this, SLOT( slotSetTime() ) )
         << i18nc("set Clock to New Time", "&Set Time..." )
         << QKeySequence( Qt::CTRL+Qt::Key_S )
-        << QIcon::fromTheme("view-history");
+        << QIcon::fromTheme("view-history", QIcon(":/icons/breeze/default/view-history.svg"));
 
     ka = actionCollection()->add<KToggleAction>("clock_startstop")
         << i18n("Stop &Clock" )
-        << QIcon::fromTheme("media-playback-pause" );
+        << QIcon::fromTheme("media-playback-pause" , QIcon(":/icons/breeze/default/media-playback-pause.svg"));
     if ( ! StartClockRunning )
         ka->toggle();
     QObject::connect( ka, SIGNAL( triggered() ), this, SLOT( slotToggleTimer() ) );
@@ -183,11 +198,11 @@ void KStars::initActions() {
     QObject::connect(data()->clock(), SIGNAL(clockToggled(bool)), this, SLOT(updateTime()) );
     actionCollection()->addAction("time_step_forward", this, SLOT( slotStepForward() ) )
         << i18n("Advance one step forward in time")
-        << QIcon::fromTheme("media-skip-forward" )
+        << QIcon::fromTheme("media-skip-forward" , QIcon(":/icons/breeze/default/media-skip-forward.svg"))
         << QKeySequence( Qt::Key_Greater, Qt::Key_Period );
     actionCollection()->addAction("time_step_backward", this, SLOT( slotStepBackward() ) )
         << i18n("Advance one step backward in time")
-        << QIcon::fromTheme("media-skip-backward" )
+        << QIcon::fromTheme("media-skip-backward" , QIcon(":/icons/breeze/default/media-skip-backward.svg"))
         << QKeySequence( Qt::Key_Less, Qt::Key_Comma );
 
     // ==== Pointing Menu ================
@@ -209,70 +224,71 @@ void KStars::initActions() {
 
     actionCollection()->addAction("find_object", this, SLOT( slotFind() ) )
         << i18n("&Find Object...")
-        << QIcon::fromTheme("edit-find")
+        << QIcon::fromTheme("edit-find", QIcon(":/icons/breeze/default/edit-find.svg") )
         << QKeySequence( Qt::CTRL+Qt::Key_F );
     actionCollection()->addAction("track_object", this, SLOT( slotTrack() ) )
         << i18n("Engage &Tracking")
-        << QIcon::fromTheme("object-locked" )
+        << QIcon::fromTheme("object-locked", QIcon(":/icons/breeze/default/object-locked.svg"))
         << QKeySequence( Qt::CTRL+Qt::Key_T  );
     actionCollection()->addAction("manual_focus", this, SLOT( slotManualFocus() ) )
         << i18n("Set Coordinates &Manually..." )
         << QKeySequence( Qt::CTRL+Qt::Key_M );
 
+    QAction *action;
+    
     // ==== View Menu ================
-    actionCollection()->addAction( KStandardAction::ZoomIn,  "zoom_in",  map(), SLOT( slotZoomIn() ) );
-    actionCollection()->addAction( KStandardAction::ZoomOut, "zoom_out", map(), SLOT( slotZoomOut() ) );
+    action = actionCollection()->addAction( KStandardAction::ZoomIn,  "zoom_in",  map(), SLOT( slotZoomIn() ) );
+    action->setIcon(QIcon::fromTheme("zoom-in", QIcon(":/icons/breeze/default/zoom-in.svg")));
+
+    action = actionCollection()->addAction( KStandardAction::ZoomOut, "zoom_out", map(), SLOT( slotZoomOut() ) );
+    action->setIcon(QIcon::fromTheme("zoom-out", QIcon(":/icons/breeze/default/zoom-out.svg")));
+    
     actionCollection()->addAction("zoom_default", map(), SLOT( slotZoomDefault() ) )
         << i18n("&Default Zoom")
-        << QIcon::fromTheme("zoom-fit-best" )
+        << QIcon::fromTheme("zoom-fit-best", QIcon(":/icons/breeze/default/zoom-fit-best.svg"))
         << QKeySequence( Qt::CTRL+Qt::Key_Z );
     actionCollection()->addAction("zoom_set", this, SLOT( slotSetZoom() ) )
         << i18n("&Zoom to Angular Size..." )
-        << QIcon::fromTheme("zoom-original" )
+        << QIcon::fromTheme("zoom-original", QIcon(":/icons/breeze/default/zoom-original.svg"))
         << QKeySequence( Qt::CTRL+Qt::SHIFT+Qt::Key_Z );
 
-    actionCollection()->addAction( KStandardAction::FullScreen, this, SLOT( slotFullScreen() ) );
+    action = actionCollection()->addAction( KStandardAction::FullScreen, this, SLOT( slotFullScreen() ) );
+    action->setIcon( QIcon::fromTheme("view-fullscreen", QIcon(":/icons/breeze/default/view-fullscreen.svg")));
 
     actionCollection()->addAction("coordsys", this, SLOT( slotCoordSys() ) )
         << (Options::useAltAz() ? i18n("Switch to star globe view (Equatorial &Coordinates)"): i18n("Switch to horizonal view (Horizontal &Coordinates)"))
-        << QKeySequence("Space" );
-
-    #ifdef HAVE_OPENGL
-    Q_ASSERT( SkyMap::Instance() ); // This assert should not fail, because SkyMap is already created by now. Just throwing it in anyway.
-    actionCollection()->addAction("opengl", SkyMap::Instance(), SLOT( slotToggleGL() ) )
-        << (Options::useGL() ? i18n("Switch to QPainter backend"): i18n("Switch to OpenGL backend"));
-    #endif
+        << QKeySequence("Space" );    
 
     actionCollection()->addAction("project_lambert", this, SLOT( slotMapProjection() ) )
         << i18n("&Lambert Azimuthal Equal-area" )
         << QKeySequence("F5" )
         << AddToGroup(projectionGroup)
-        << Checked(Options::projection() == SkyMap::Lambert);
+        << Checked(Options::projection() == Projector::Lambert);
     actionCollection()->addAction("project_azequidistant", this, SLOT( slotMapProjection() ) )
         << i18n("&Azimuthal Equidistant" )
         << QKeySequence("F6" )
         << AddToGroup(projectionGroup)
-        << Checked(Options::projection() == SkyMap::AzimuthalEquidistant);
+        << Checked(Options::projection() == Projector::AzimuthalEquidistant);
     actionCollection()->addAction("project_orthographic", this, SLOT( slotMapProjection() ) )
         << i18n("&Orthographic" )
         << QKeySequence("F7" )
         << AddToGroup(projectionGroup)
-        << Checked(Options::projection() == SkyMap::Orthographic);
+        << Checked(Options::projection() == Projector::Orthographic);
     actionCollection()->addAction("project_equirectangular", this, SLOT( slotMapProjection() ) )
         << i18n("&Equirectangular" )
         << QKeySequence("F8" )
         << AddToGroup(projectionGroup)
-        << Checked(Options::projection() == SkyMap::Equirectangular);
+        << Checked(Options::projection() == Projector::Equirectangular);
     actionCollection()->addAction("project_stereographic", this, SLOT( slotMapProjection() ) )
         << i18n("&Stereographic" )
         << QKeySequence("F9" )
         << AddToGroup(projectionGroup)
-        << Checked(Options::projection() == SkyMap::Stereographic);
+        << Checked(Options::projection() == Projector::Stereographic);
     actionCollection()->addAction("project_gnomonic", this, SLOT( slotMapProjection() ) )
         << i18n("&Gnomonic" )
         << QKeySequence("F10" )
         << AddToGroup(projectionGroup)
-        << Checked(Options::projection() == SkyMap::Gnomonic);
+        << Checked(Options::projection() == Projector::Gnomonic);
 
     //Settings Menu:
     //Info Boxes option actions
@@ -345,17 +361,25 @@ void KStars::initActions() {
     fovActionMenu = actionCollection()->add<KActionMenu>("fovsymbols" );
     fovActionMenu->setText( i18n("&FOV Symbols" ) );
     fovActionMenu->setDelayed(false);
-    fovActionMenu->setIcon(QIcon::fromTheme("crosshairs"));
+    fovActionMenu->setIcon(QIcon::fromTheme("crosshairs", QIcon(":/icons/breeze/default/crosshairs.svg")));
+    FOVManager::readFOVs();
     repopulateFOV();
 
     actionCollection()->addAction("geolocation", this, SLOT( slotGeoLocator() ) )
         << i18nc("Location on Earth", "&Geographic..." )
-        << QIcon::fromTheme("applications-internet" )
+        << QIcon::fromTheme("kstars_planets" , QIcon(":/icons/breeze/default/kstars_planets.svg"))
         << QKeySequence( Qt::CTRL+Qt::Key_G );
-    actionCollection()->addAction( KStandardAction::Preferences, "configure", this, SLOT( slotViewOps() ) );
+    ka = actionCollection()->addAction( KStandardAction::Preferences, "configure", this, SLOT( slotViewOps() ) );
+    //I am not sure what icon preferences is supposed to be.
+    //ka->setIcon( QIcon::fromTheme("", QIcon(":/icons/breeze/default/.svg")));
+    
     actionCollection()->addAction("startwizard", this, SLOT( slotWizard() ) )
         << i18n("Startup Wizard..." )
-        << QIcon::fromTheme("tools-wizard" );
+        << QIcon::fromTheme("tools-wizard", QIcon(":/icons/breeze/default/tools-wizard.svg"));
+
+    // Manual data entry
+    actionCollection()->addAction( "manual_add_dso", this, SLOT( slotAddDeepSkyObject() ) )
+        << i18n( "Manually add a deep-sky object" );
 
     // Updates actions
     actionCollection()->addAction( "update_comets", this, SLOT( slotUpdateComets() ) )
@@ -370,7 +394,7 @@ void KStars::initActions() {
     //Tools Menu:
     actionCollection()->addAction("astrocalculator", this, SLOT( slotCalculator() ) )
         << i18n("Calculator")
-        << QIcon::fromTheme("accessories-calculator" )
+        << QIcon::fromTheme("accessories-calculator", QIcon(":/icons/breeze/default/accessories-calculator.svg"))
         << QKeySequence( Qt::CTRL+Qt::Key_C );
 
    /* FIXME Enable once port to KF5 is complete for moonphasetool
@@ -446,11 +470,11 @@ void KStars::initActions() {
 #ifndef Q_OS_WIN
         actionCollection()->addAction("telescope_wizard", this, SLOT( slotTelescopeWizard() ) )
             << i18n("Telescope Wizard...")
-            << QIcon::fromTheme("tools-wizard" );
+            << QIcon::fromTheme("tools-wizard", QIcon(":/icons/breeze/default/tools-wizard.svg"));
 #endif
         actionCollection()->addAction("device_manager", this, SLOT( slotINDIDriver() ) )
             << i18n("Device Manager...")
-            << QIcon::fromTheme("network-server" )
+            << QIcon::fromTheme("network-server", QIcon(":/icons/breeze/default/network-server.svg"))
             << QKeySequence(Qt::CTRL+Qt::Key_D);
         ka = actionCollection()->addAction("indi_cpl", this, SLOT( slotINDIPanel() ) )
             << i18n("INDI Control Panel...");
@@ -462,9 +486,9 @@ void KStars::initActions() {
 #endif
 
     //Help Menu:
-    actionCollection()->addAction( KStandardAction::TipofDay, "help_tipofday", this, SLOT( slotTipOfDay() ) )
-	->setWhatsThis(i18n("Displays the Tip of the Day"));
-
+    ka = actionCollection()->addAction( KStandardAction::TipofDay, "help_tipofday", this, SLOT( slotTipOfDay() ) );
+	ka->setWhatsThis(i18n("Displays the Tip of the Day"));
+    ka->setIcon( QIcon::fromTheme("help-hint", QIcon(":/icons/breeze/default/help-hint.svg")));
     //	KStandardAction::help(this, SLOT( appHelpActivated() ), actionCollection(), "help_contents" );
 
     //Add timestep widget for toolbar
@@ -481,75 +505,75 @@ void KStars::initActions() {
     // ==== viewToolBar actions ================
     actionCollection()->add<KToggleAction>("show_stars", this, SLOT( slotViewToolBar() ) )
         << i18nc("Toggle Stars in the display", "Stars" )
-        << QIcon::fromTheme("kstars_stars", QIcon(":/icons/stars.png") )
+        << QIcon::fromTheme("kstars_stars", QIcon(":/icons/breeze/default/kstars_stars.svg") )
         << ToolTip( i18n("Toggle stars") );
     actionCollection()->add<KToggleAction>("show_deepsky", this, SLOT( slotViewToolBar() ) )
         << i18nc("Toggle Deep Sky Objects in the display", "Deep Sky" )
-        << QIcon::fromTheme("kstars_deepsky" , QIcon(":/icons/deepsky.png") )
+        << QIcon::fromTheme("kstars_deepsky" , QIcon(":/icons/breeze/default/kstars_deepsky.svg") )
         << ToolTip( i18n("Toggle deep sky objects") );
     actionCollection()->add<KToggleAction>("show_planets", this, SLOT( slotViewToolBar() ) )
         << i18nc("Toggle Solar System objects in the display", "Solar System" )
-        << QIcon::fromTheme("kstars_planets" , QIcon(":/icons/planets.png"))
+        << QIcon::fromTheme("kstars_planets" , QIcon(":/icons/breeze/default/kstars_planets.svg"))
         << ToolTip( i18n("Toggle Solar system objects") );
     actionCollection()->add<KToggleAction>("show_clines", this, SLOT( slotViewToolBar() ) )
         << i18nc("Toggle Constellation Lines in the display", "Const. Lines" )
-        << QIcon::fromTheme("kstars_clines" , QIcon(":/icons/clines.png"))
+        << QIcon::fromTheme("kstars_clines" , QIcon(":/icons/breeze/default/kstars_clines.svg"))
         << ToolTip( i18n("Toggle constellation lines") );
     actionCollection()->add<KToggleAction>("show_cnames", this, SLOT( slotViewToolBar() ) )
         << i18nc("Toggle Constellation Names in the display", "Const. Names" )
-        << QIcon::fromTheme("kstars_cnames" , QIcon(":/icons/cnames.png"))
+        << QIcon::fromTheme("kstars_cnames" , QIcon(":/icons/breeze/default/kstars_cnames.svg"))
         << ToolTip( i18n("Toggle constellation names") );
     actionCollection()->add<KToggleAction>("show_cbounds", this, SLOT( slotViewToolBar() ) )
         << i18nc("Toggle Constellation Boundaries in the display", "C. Boundaries" )
-        << QIcon::fromTheme("kstars_cbound" , QIcon(":/icons/cbound.png"))
+        << QIcon::fromTheme("kstars_cbound" , QIcon(":/icons/breeze/default/kstars_cbound.svg"))
         << ToolTip( i18n("Toggle constellation boundaries") );
     actionCollection()->add<KToggleAction>("show_constellationart", this, SLOT( slotViewToolBar() ) )
         << xi18nc("Toggle Constellation Art in the display", "C. Art (BETA)" )
-        << QIcon::fromTheme("kstars_constellationart" , QIcon(":/icons/constellationart.png"))
+        << QIcon::fromTheme("kstars_constellationart" , QIcon(":/icons/breeze/default/kstars_constellationart.svg"))
         << ToolTip( xi18n("Toggle constellation art (BETA)") );
     actionCollection()->add<KToggleAction>("show_mw", this, SLOT( slotViewToolBar() ) )
         << i18nc("Toggle Milky Way in the display", "Milky Way" )
-        << QIcon::fromTheme("kstars_mw" , QIcon(":/icons/mw.png"))
+        << QIcon::fromTheme("kstars_mw" , QIcon(":/icons/breeze/default/kstars_mw.svg"))
         << ToolTip( i18n("Toggle milky way") );
     actionCollection()->add<KToggleAction>("show_equatorial_grid", this, SLOT( slotViewToolBar() ) )
         << i18nc("Toggle Equatorial Coordinate Grid in the display", "Equatorial coord. grid" )
-        << QIcon::fromTheme("kstars_grid" , QIcon(":/icons/grid.png") )
+        << QIcon::fromTheme("kstars_grid" , QIcon(":/icons/breeze/default/kstars_grid.svg") )
         << ToolTip( i18n("Toggle equatorial coordinate grid") );
     actionCollection()->add<KToggleAction>("show_horizontal_grid", this, SLOT( slotViewToolBar() ) )
         << i18nc("Toggle Horizontal Coordinate Grid in the display", "Horizontal coord. grid" )
-        << QIcon::fromTheme("kstars_hgrid" , QIcon(":/icons/hgrid.png") )
+        << QIcon::fromTheme("kstars_hgrid" , QIcon(":/icons/breeze/default/kstars_hgrid.svg") )
         << ToolTip( i18n("Toggle horizontal coordinate grid") );
     actionCollection()->add<KToggleAction>("show_horizon", this, SLOT( slotViewToolBar() ) )
         << i18nc("Toggle the opaque fill of the ground polygon in the display", "Ground" )
-        << QIcon::fromTheme("kstars_horizon" , QIcon(":/icons/horizon.png") )
+        << QIcon::fromTheme("kstars_horizon" , QIcon(":/icons/breeze/default/kstars_horizon.svg") )
         << ToolTip( i18n("Toggle opaque ground") );
     actionCollection()->add<KToggleAction>("show_flags", this, SLOT( slotViewToolBar() ) )
         << i18nc("Toggle flags in the display", "Flags" )
-        << QIcon::fromTheme("kstars_flag" , QIcon(":/icons/flag.png") )
+        << QIcon::fromTheme("kstars_flag" , QIcon(":/icons/breeze/default/kstars_flag.svg") )
         << ToolTip( i18n("Toggle flags") );
     actionCollection()->add<KToggleAction>("show_satellites", this, SLOT( slotViewToolBar() ) )
         << i18nc("Toggle satellites in the display", "Satellites" )
-        << QIcon::fromTheme("kstars_satellites" , QIcon(":/icons/satellites.png"))
+        << QIcon::fromTheme("kstars_satellites" , QIcon(":/icons/breeze/default/kstars_satellites.svg"))
         << ToolTip( i18n("Toggle satellites") );
     actionCollection()->add<KToggleAction>("show_supernovae", this, SLOT( slotViewToolBar() ) )
         << i18nc("Toggle supernovae in the display", "Supernovae" )
-        << QIcon::fromTheme("kstars_supernovae" , QIcon(":/icons/supernovae.png"))
+        << QIcon::fromTheme("kstars_supernovae" , QIcon(":/icons/breeze/default/kstars_supernovae.svg"))
         << ToolTip( i18n("Toggle supernovae") );
 
 #ifdef HAVE_INDI
     // ==== INDIToolBar actions ================
     actionCollection()->add<KToggleAction>("show_ekos", this, SLOT( slotINDIToolBar() ) )
         << i18nc("Toggle Ekos in the display", "Ekos" )
-        << QIcon::fromTheme("kstars_ekos", QIcon(":/icons/ekos.png") )
+        << QIcon::fromTheme("kstars_ekos", QIcon(":/icons/breeze/default/kstars_ekos.svg") )
         << ToolTip( i18n("Toggle Ekos") );
     ka = actionCollection()->add<KToggleAction>("show_control_panel", this, SLOT( slotINDIToolBar() ) )
         << i18nc("Toggle the INDI Control Panel in the display", "INDI Control Panel" )
-        << QIcon::fromTheme("kstars_indi", QIcon(":/icons/indi.png") )
+        << QIcon::fromTheme("kstars_indi", QIcon(":/icons/breeze/default/kstars_indi.svg") )
         << ToolTip( i18n("Toggle INDI Control Panel") );
     ka->setEnabled(false);
     ka = actionCollection()->add<KToggleAction>("show_fits_viewer", this, SLOT( slotINDIToolBar() ) )
         << i18nc("Toggle the FITS Viewer in the display", "FITS Viewer" )
-        << QIcon::fromTheme("kstars_fitsviewer" , QIcon(":/icons/fitsviewer.png") )
+        << QIcon::fromTheme("kstars_fitsviewer" , QIcon(":/icons/breeze/default/kstars_fitsviewer.svg") )
         << ToolTip( i18n("Toggle FITS Viewer") );
     ka->setEnabled(false);
 #endif
@@ -560,18 +584,21 @@ void KStars::initActions() {
 
 void KStars::repopulateFOV() {
     // Read list of all FOVs
-    qDeleteAll( data()->availFOVs );
-    data()->availFOVs = FOV::readFOVs();
+    //qDeleteAll( data()->availFOVs );
+    data()->availFOVs = FOVManager::getFOVs();
     data()->syncFOV();
 
     // Iterate through FOVs
     fovActionMenu->menu()->clear();
-    foreach(FOV* fov, data()->availFOVs) {
+    foreach(FOV* fov, data()->availFOVs)
+    {
         KToggleAction *kta = actionCollection()->add<KToggleAction>( fov->name() );
         kta->setText( fov->name() );
-        if( Options::fOVNames().contains( fov->name() ) ) {
+        if( Options::fOVNames().contains( fov->name() ) )
+        {
             kta->setChecked(true);
         }
+
         fovActionMenu->addAction( kta );
         connect( kta, SIGNAL( toggled( bool ) ), this, SLOT( slotTargetSymbol(bool) ) );
     }
