@@ -29,7 +29,9 @@
 
 #include "Options.h"
 #include "kstarsdata.h"
+#ifndef KSTARS_LITE
 #include "skymap.h"
+#endif
 #include "skyobjects/starobject.h"
 #include "skymesh.h"
 #include "binfilehelper.h"
@@ -45,7 +47,7 @@ DeepStarComponent::DeepStarComponent( SkyComposite *parent, QString fileName, fl
     ListComponent(parent),
     m_reindexNum( J2000 ),
     triggerMag( trigMag ),
-    m_FaintMagnitude(-5.0), 
+    m_FaintMagnitude(-5.0),
     staticStars( staticstars ),
     dataFileName( fileName )
 {
@@ -106,7 +108,7 @@ bool DeepStarComponent::loadStaticStars() {
         if( !SB )
             qDebug() << "ERROR: Could not allocate new StarBlock to hold shallow unnamed stars for trixel " << trixel << endl;
         m_starBlockList.at( trixel )->setStaticBlock( SB );
-        
+
         for(unsigned long j = 0; j < (unsigned long) starReader.getRecordCount(i); ++j) {
             bool fread_success = false;
             if( starReader.guessRecordSize() == 32 )
@@ -118,7 +120,7 @@ bool DeepStarComponent::loadStaticStars() {
                 qDebug() << "ERROR: Could not read starData structure for star #" << j << " under trixel #" << trixel << endl;
             }
 
-            /* Swap Bytes when required */            
+            /* Swap Bytes when required */
             if( starReader.getByteSwap() ) {
                 if( starReader.guessRecordSize() == 32 )
                     byteSwap( &stardata );
@@ -129,10 +131,17 @@ bool DeepStarComponent::loadStaticStars() {
             /* Initialize star with data just read. */
             StarObject* star;
             if( starReader.guessRecordSize() == 32 )
+        #ifdef KSTARS_LITE
+                star = &(SB->addStar( stardata )->star);
+        #else
                 star = SB->addStar( stardata );
+        #endif
             else
+        #ifdef KSTARS_LITE
+                star = &(SB->addStar( stardata )->star);
+        #else
                 star = SB->addStar( deepstardata );
-            
+        #endif
             if( star ) {
                 KStarsData* data = KStarsData::Instance();
                 star->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
@@ -166,15 +175,27 @@ bool openIndexFile( ) {
     return 0;
 }
 
-//This function is empty for a reason; we override the normal 
+//This function is empty for a reason; we override the normal
 //update function in favor of JiT updates for stars.
 void DeepStarComponent::update( KSNumbers * )
 {}
 
 // TODO: Optimize draw, if it is worth it.
 void DeepStarComponent::draw( SkyPainter *skyp ) {
+#ifndef KSTARS_LITE
     if ( !fileOpened ) return;
 
+#ifdef PROFILE_SINCOS
+    long trig_calls_here = - dms::trig_function_calls;
+    long trig_redundancy_here = - dms::redundant_trig_function_calls;
+    long cachingdms_bad_uses = -CachingDms::cachingdms_bad_uses;
+    dms::seconds_in_trig = 0.;
+#endif
+
+#ifdef PROFILE_UPDATECOORDS
+    StarObject::updateCoordsCpuTime = 0.;
+    StarObject::starsUpdated = 0;
+#endif
     SkyMap *map = SkyMap::Instance();
     KStarsData* data = KStarsData::Instance();
     UpdateID updateID = data->updateID();
@@ -239,15 +260,15 @@ void DeepStarComponent::draw( SkyPainter *skyp ) {
             for( int i = 0; i < m_starBlockList.at( currentRegion )->getBlockCount(); ++i ) {
                 StarBlock *prevBlock = ( ( i >= 1 ) ? m_starBlockList.at( currentRegion )->block( i - 1 ) : NULL );
                 StarBlock *block = m_starBlockList.at( currentRegion )->block( i );
-                
+
                 if( i == 0  &&  !m_StarBlockFactory->markFirst( block ) )
                     qDebug() << "markFirst failed in trixel" << currentRegion;
                 if( i > 0   &&  !m_StarBlockFactory->markNext( prevBlock, block ) )
                     qDebug() << "markNext failed in trixel" << currentRegion << "while marking block" << i;
-                if( i < m_starBlockList.at( currentRegion )->getBlockCount() 
+                if( i < m_starBlockList.at( currentRegion )->getBlockCount()
                     && m_starBlockList.at( currentRegion )->block( i )->getFaintMag() < maglim )
                     break;
-                    
+
             }
         }
         t_updateCache = t.restart();
@@ -264,24 +285,24 @@ void DeepStarComponent::draw( SkyPainter *skyp ) {
         // Static stars need not execute fillToMag
 
 	if( !staticStars && !m_starBlockList.at( currentRegion )->fillToMag( maglim ) && maglim <= m_FaintMagnitude * ( 1 - 1.5/16 ) ) {
-            qDebug() << "SBL::fillToMag( " << maglim << " ) failed for trixel " 
+            qDebug() << "SBL::fillToMag( " << maglim << " ) failed for trixel "
                      << currentRegion << " !"<< endl;
 	}
 
         t_dynamicLoad += t.restart();
 
-        //        qDebug() << "Drawing SBL for trixel " << currentRegion << ", SBL has " 
+        //        qDebug() << "Drawing SBL for trixel " << currentRegion << ", SBL has "
         //                 <<  m_starBlockList[ currentRegion ]->getBlockCount() << " blocks" << endl;
 
         for( int i = 0; i < m_starBlockList.at( currentRegion )->getBlockCount(); ++i ) {
             StarBlock *block = m_starBlockList.at( currentRegion )->block( i );
-            //            qDebug() << "---> Drawing stars from block " << i << " of trixel " << 
+            //            qDebug() << "---> Drawing stars from block " << i << " of trixel " <<
             //                currentRegion << ". SB has " << block->getStarCount() << " stars" << endl;
             for( int j = 0; j < block->getStarCount(); j++ ) {
 
                 StarObject *curStar = block->star( j );
 
-                //                qDebug() << "We claim that he's from trixel " << currentRegion 
+                //                qDebug() << "We claim that he's from trixel " << currentRegion
                 //<< ", and indexStar says he's from " << m_skyMesh->indexStar( curStar );
 
                 if ( curStar->updateID != updateID )
@@ -298,12 +319,28 @@ void DeepStarComponent::draw( SkyPainter *skyp ) {
         }
 
         // DEBUG: Uncomment to identify problems with Star Block Factory / preservation of Magnitude Order in the LRU Cache
-        //        verifySBLIntegrity();        
+        //        verifySBLIntegrity();
         t_drawUnnamed += t.restart();
 
     }
     m_skyMesh->inDraw( false );
+#ifdef PROFILE_SINCOS
+    trig_calls_here += dms::trig_function_calls;
+    trig_redundancy_here += dms::redundant_trig_function_calls;
+    cachingdms_bad_uses += CachingDms::cachingdms_bad_uses;
+    qDebug() << "Spent " << dms::seconds_in_trig << " seconds doing " << trig_calls_here << " trigonometric function calls amounting to an average of " << 1000.0 * dms::seconds_in_trig/double( trig_calls_here ) << " ms per call";
+    qDebug() << "Redundancy of trig calls in this draw: " << double( trig_redundancy_here ) / double( trig_calls_here ) * 100. << "%";
+    qDebug() << "CachedDms constructor calls so far: " << CachingDms::cachingdms_constructor_calls;
+    qDebug() << "Caching has prevented " << CachingDms::cachingdms_delta << " redundant trig function calls";
+    qDebug() << "Bad cache uses in this draw: " << cachingdms_bad_uses;
+#endif
+#ifdef PROFILE_UPDATECOORDS
+    qDebug() << "Spent " << StarObject::updateCoordsCpuTime << " seconds updating " << StarObject::starsUpdated << " stars' coordinates (StarObject::updateCoords) for an average of " << double( StarObject::updateCoordsCpuTime )/double( StarObject::starsUpdated ) * 1.e6 << " us per star.";
+#endif
 
+#else
+    Q_UNUSED(skyp)
+#endif
 }
 
 bool DeepStarComponent::openDataFile() {
@@ -372,6 +409,9 @@ SkyObject* DeepStarComponent::objectNearest( SkyPoint *p, double &maxrad )
 {
     StarObject *oBest = 0;
 
+#ifdef KSTARS_LITE
+    m_zoomMagLimit = StarComponent::zoomMagnitudeLimit();
+#endif
     if( !fileOpened )
         return NULL;
 
@@ -384,10 +424,14 @@ SkyObject* DeepStarComponent::objectNearest( SkyPoint *p, double &maxrad )
         for( int i = 0; i < m_starBlockList.at( currentRegion )->getBlockCount(); ++i ) {
             StarBlock *block = m_starBlockList.at( currentRegion )->block( i );
             for( int j = 0; j < block->getStarCount(); ++j ) {
+#ifdef KSTARS_LITE
+                StarObject* star =  &(block->star( j )->star);
+#else
                 StarObject* star =  block->star( j );
+#endif
                 if( !star ) continue;
                 if ( star->mag() > m_zoomMagLimit ) continue;
-                
+
                 double r = star->angularDistanceTo( p ).Degrees();
                 if ( r < maxrad ) {
                     oBest = star;
@@ -404,7 +448,7 @@ SkyObject* DeepStarComponent::objectNearest( SkyPoint *p, double &maxrad )
     // different method and should be called after all other
     // candidates (eg: DeepSkyObject::objectNearest()) have been
     // called.
-    
+
     return oBest;
 }
 
@@ -439,7 +483,11 @@ bool DeepStarComponent::starsInAperture( QList<StarObject *> &list, const SkyPoi
         for( int i = 0; i < sbl->getBlockCount(); ++i ) {
             StarBlock *block = sbl->block( i );
             for( int j = 0; j < block->getStarCount(); ++j ) {
+#ifdef KSTARS_LITE
+                StarObject *star = &(block->star( j )->star);
+#else
                 StarObject *star = block->star( j );
+#endif
                 if( star->mag() > maglim )
                     break; // Stars are organized by magnitude, so this should work
                 if( star->angularDistanceTo( &center ).Degrees() <= radius )
@@ -481,13 +529,13 @@ bool DeepStarComponent::verifySBLIntegrity() {
                 faintMag = block->getBrightMag();
             // NOTE: Assumes 2 decimal places in magnitude field. TODO: Change if it ever does change
             if( block->getBrightMag() != faintMag && ( block->getBrightMag() - faintMag ) > 0.5) {
-                qDebug() << "Trixel " << trixel << ": ERROR: faintMag of prev block = " << faintMag 
+                qDebug() << "Trixel " << trixel << ": ERROR: faintMag of prev block = " << faintMag
                          << ", brightMag of block #" << i << " = " << block->getBrightMag();
                 integrity = false;
             }
             if( i > 1 && ( !block->prev ) )
                 qDebug() << "Trixel " << trixel << ": ERROR: Block" << i << "is unlinked in LRU Cache";
-            if( block->prev && block->prev->parent == m_starBlockList[ trixel ] 
+            if( block->prev && block->prev->parent == m_starBlockList[ trixel ]
                 && block->prev != m_starBlockList[ trixel ]->block( i - 1 ) ) {
                 qDebug() << "Trixel " << trixel << ": ERROR: SBF LRU Cache linked list seems to be broken at before block " << i << endl;
                 integrity = false;
