@@ -16,7 +16,11 @@
  ***************************************************************************/
 
 #include "supernovaecomponent.h"
+#ifndef KSTARS_LITE
 #include "skymap.h"
+#else
+#include "kstarslite.h"
+#endif
 #include "skypainter.h"
 #include "skymesh.h"
 #include "skylabeler.h"
@@ -63,6 +67,7 @@ void SupernovaeComponent::loadData()
     //m_ObjectList.clear();
     latest.clear();
     objectNames(SkyObject::SUPERNOVA).clear();
+    objectLists(SkyObject::SUPERNOVA).clear();
 
     //SN,  Host Galaxy,  Date,  R.A.,  Dec.,  Offset,  Mag.,  Disc.Ref.,  SN Position,  Posn.Ref.,  Typ,  SN,  Discoverer(s)
     QList< QPair<QString,KSParser::DataTypes> > sequence;
@@ -105,9 +110,11 @@ void SupernovaeComponent::loadData()
         if (magnitude == KSParser::EBROKEN_FLOAT)
             magnitude = 99.9;
 
-        if (m_ObjectList.empty() || !findByName(serialNo))
+        Supernova *sup = static_cast<Supernova*>(findByName(serialNo));
+
+        if (m_ObjectList.empty() || !sup)
         {
-            Supernova *sup = new Supernova(ra, dec, date, magnitude, serialNo,
+            sup = new Supernova(ra, dec, date, magnitude, serialNo,
                     type, hostGalaxy, offset, discoverers);
 
             sup->EquatorialToHorizontal(KStarsData::Instance()->lst(),
@@ -117,6 +124,7 @@ void SupernovaeComponent::loadData()
             latest.append(sup);
         }
 
+        if(sup) objectLists(SkyObject::SUPERNOVA).append(QPair<QString, const SkyObject*>(serialNo, sup));
         objectNames(SkyObject::SUPERNOVA).append(serialNo);
     }
     //notifyNewSupernovae();
@@ -188,6 +196,7 @@ void SupernovaeComponent::draw(SkyPainter *skyp)
 
 void SupernovaeComponent::notifyNewSupernovae()
 {
+#ifndef KSTARS_LITE
     //qDebug()<<"New Supernovae discovered";
     QList<SkyObject*> latestList;
     foreach (SkyObject * so, latest)
@@ -211,6 +220,7 @@ void SupernovaeComponent::notifyNewSupernovae()
     }
 //     if (!latest.empty())
 //         KMessageBox::informationList(0, i18n("New Supernovae discovered!"), latestList, i18n("New Supernovae discovered!"));
+#endif
 }
 
 
@@ -243,9 +253,14 @@ void SupernovaeComponent::slotDataFileUpdateFinished( int exitCode, QProcess::Ex
                 errmsg = i18n( "Python process that updates the supernova information failed with error code %1. This could likely be because the computer is not connected to the internet or because the server containing supernova information is not responding.", QString::number( exitCode ) );
                 break;
         }
+        #ifndef KSTARS_LITE
         if( KStars::Instance() && SkyMap::Instance() ) // Displaying a message box causes entry of control into the Qt event loop. Can lead to segfault if we are checking for supernovae alerts during initialization!
             KMessageBox::sorry( 0, errmsg, i18n("Supernova information update failed") );
         // FIXME: There should be a better way to check if KStars is fully initialized. Maybe we should have a static boolean in the KStars class. --asimha
+        #else
+        if( KStarsLite::Instance() && SkyMapLite::Instance() ) // Displaying a message box causes entry of control into the Qt event loop. Can lead to segfault if we are checking for supernovae alerts during initialization!
+            qDebug() << errmsg << i18n("Supernova information update failed");
+        #endif
     }
     else {
         //qDebug()<<"HERE";
