@@ -19,9 +19,6 @@
 
 #include "skyqpainter.h"
 
-#include <QMap>
-#include <QWidget>
-
 #include "kstarsdata.h"
 #include "Options.h"
 #include "skymap.h"
@@ -43,6 +40,11 @@
 #include "projections/projector.h"
 #include "ksutils.h"
 
+#include <QMap>
+#include <QWidget>
+
+#include <functional>
+
 namespace {
 
     // Convert spectral class to numerical index.
@@ -74,6 +76,8 @@ namespace {
 }
 
 int SkyQPainter::starColorMode = 0;
+QColor SkyQPainter::m_starColor = QColor();
+QMap<char, QColor> SkyQPainter::ColorMap = QMap<char, QColor>();
 
 
 SkyQPainter::SkyQPainter( QPaintDevice *pd )
@@ -141,38 +145,22 @@ void SkyQPainter::setBrush(const QBrush& brush)
 void SkyQPainter::initStarImages()
 {
 
-    QMap<char, QColor> ColorMap;
     const int starColorIntensity = Options::starColorIntensity();
 
+    ColorMap.clear();
     switch( Options::starColorMode() ) {
     case 1: // Red stars.
-        ColorMap.insert( 'O', QColor::fromRgb( 255,   0,   0 ) );
-        ColorMap.insert( 'B', QColor::fromRgb( 255,   0,   0 ) );
-        ColorMap.insert( 'A', QColor::fromRgb( 255,   0,   0 ) );
-        ColorMap.insert( 'F', QColor::fromRgb( 255,   0,   0 ) );
-        ColorMap.insert( 'G', QColor::fromRgb( 255,   0,   0 ) );
-        ColorMap.insert( 'K', QColor::fromRgb( 255,   0,   0 ) );
-        ColorMap.insert( 'M', QColor::fromRgb( 255,   0,   0 ) );
+        m_starColor = Qt::red;
         break;
     case 2: // Black stars.
-        ColorMap.insert( 'O', QColor::fromRgb(   0,   0,   0 ) );
-        ColorMap.insert( 'B', QColor::fromRgb(   0,   0,   0 ) );
-        ColorMap.insert( 'A', QColor::fromRgb(   0,   0,   0 ) );
-        ColorMap.insert( 'F', QColor::fromRgb(   0,   0,   0 ) );
-        ColorMap.insert( 'G', QColor::fromRgb(   0,   0,   0 ) );
-        ColorMap.insert( 'K', QColor::fromRgb(   0,   0,   0 ) );
-        ColorMap.insert( 'M', QColor::fromRgb(   0,   0,   0 ) );
+        m_starColor = Qt::black;
         break;
     case 3: // White stars
-        ColorMap.insert( 'O', QColor::fromRgb( 255, 255, 255 ) );
-        ColorMap.insert( 'B', QColor::fromRgb( 255, 255, 255 ) );
-        ColorMap.insert( 'A', QColor::fromRgb( 255, 255, 255 ) );
-        ColorMap.insert( 'F', QColor::fromRgb( 255, 255, 255 ) );
-        ColorMap.insert( 'G', QColor::fromRgb( 255, 255, 255 ) );
-        ColorMap.insert( 'K', QColor::fromRgb( 255, 255, 255 ) );
-        ColorMap.insert( 'M', QColor::fromRgb( 255, 255, 255 ) );
+        m_starColor = Qt::white;
+        break;
     case 0:  // Real color
     default: // And use real color for everything else
+        m_starColor = QColor();
         ColorMap.insert( 'O', QColor::fromRgb(   0,   0, 255 ) );
         ColorMap.insert( 'B', QColor::fromRgb(   0, 200, 255 ) );
         ColorMap.insert( 'A', QColor::fromRgb(   0, 255, 255 ) );
@@ -180,6 +168,16 @@ void SkyQPainter::initStarImages()
         ColorMap.insert( 'G', QColor::fromRgb( 255, 255,   0 ) );
         ColorMap.insert( 'K', QColor::fromRgb( 255, 100,   0 ) );
         ColorMap.insert( 'M', QColor::fromRgb( 255,   0,   0 ) );
+        break;
+    }
+    if ( ColorMap.isEmpty() ) {
+        ColorMap.insert( 'O', m_starColor );
+        ColorMap.insert( 'B', m_starColor );
+        ColorMap.insert( 'A', m_starColor );
+        ColorMap.insert( 'F', m_starColor );
+        ColorMap.insert( 'G', m_starColor );
+        ColorMap.insert( 'K', m_starColor );
+        ColorMap.insert( 'M', m_starColor );
     }
 
     foreach( char color, ColorMap.keys() ) {
@@ -272,8 +270,16 @@ void SkyQPainter::drawSkyPolyline(LineList* list, SkipList* skipList, LineListLa
             doSkip = skipList->skip(j);
         }
 
+        bool pointsVisible = false;
+        //Temporary solution to avoid random lines in Gnomonic projection and draw lines up to horizon
+        if(SkyMap::Instance()->projector()->type() == Projector::Gnomonic) {
+            if ( isVisible && isVisibleLast ) pointsVisible = true;
+        } else {
+            if ( isVisible || isVisibleLast ) pointsVisible = true;
+        }
+
         if ( !doSkip ) {
-            if ( isVisible && isVisibleLast ) {
+            if(pointsVisible) {
                 drawLine( oLast, oThis );
                 if ( label )
                     label->updateLabelCandidates( oThis.x(), oThis.y(), list, j );
@@ -412,7 +418,7 @@ bool SkyQPainter::drawPointSource(SkyPoint* loc, float mag, char sp)
 void SkyQPainter::drawPointSource(const QPointF& pos, float size, char sp)
 {
     int isize = qMin(static_cast<int>(size), 14);
-    if( !m_vectorStars || ( starColorMode <=0 || starColorMode > 3 )  ) {
+    if( !m_vectorStars || starColorMode == 0  ) {
         // Draw stars as bitmaps, either because we were asked to, or because we're painting real colors
         QPixmap* im = imageCache[ harvardToIndex(sp) ][isize];
         float offset = 0.5 * im->width();
@@ -420,22 +426,16 @@ void SkyQPainter::drawPointSource(const QPointF& pos, float size, char sp)
     }
     else {
         // Draw stars as vectors, for better printing / SVG export etc.
-        static QColor color; // FIXME: This slows down things a bit, but we won't care because we're not painting the SkyMap this way anyway.
-        switch( Options::starColorMode() ) {
-        case 1:
-            color = QColor::fromRgb(255, 0, 0);
-            break;
-        case 2:
-            color = QColor::fromRgb(0, 0, 0);
-            break;
-        case 3:
-            color = QColor::fromRgb(255, 255, 255);
-            break;
-        default:
-            Q_ASSERT( false );
+        if ( starColorMode != 4 ) {
+            setPen( m_starColor );
+            setBrush( m_starColor );
+        }
+        else {
+            // Note: This is not efficient, but we use vector stars only when plotting SVG, not when drawing the skymap, so speed is not very important.
+            QColor c = ColorMap.value( sp, Qt::white );
+            setPen( c );
+            setBrush( c );
         }
-        setPen( color );
-        setBrush( color );
 
         // Be consistent with old raster representation
         if( size > 14 )
@@ -524,7 +524,6 @@ bool SkyQPainter::drawDeepSkyImage(const QPointF& pos, DeepSkyObject* obj, float
     return true;
 }
 
-//FIXME: Do we really need two versions of all of this code? (int/float)
 void SkyQPainter::drawDeepSkySymbol(const QPointF &pos, int type, float size, float e, float positionAngle)
 {
     float x = pos.x();
@@ -557,71 +556,75 @@ void SkyQPainter::drawDeepSkySymbol(const QPointF &pos, int type, float size, fl
 
     QBrush tempBrush;
 
+    std::function<void( float, float, float, float )> lambdaDrawEllipse;
+    std::function<void( float, float, float, float )> lambdaDrawLine;
+    std::function<void( float, float, float, float )> lambdaDrawCross;
+
+    if ( Options::useAntialias() ) {
+        lambdaDrawEllipse = [this]( float x, float y, float width, float height ) {
+            drawEllipse( QRectF( x, y, width, height ) );
+        };
+        lambdaDrawLine = [this]( float x1, float y1, float x2, float y2 ) {
+            drawLine( QLineF( x1, y1, x2, y2 ) );
+        };
+        lambdaDrawCross = [this]( float centerX, float centerY, float sizeX, float sizeY ) {
+            drawLine( QLineF( centerX - sizeX/2., centerY, centerX + sizeX/2., centerY ) );
+            drawLine( QLineF( centerX, centerY - sizeY/2., centerX, centerY + sizeY/2. ) );
+        };
+    }
+    else {
+        lambdaDrawEllipse = [this]( float x, float y, float width, float height ) {
+            drawEllipse( QRect( x, y, width, height ) );
+        };
+        lambdaDrawLine = [this]( float x1, float y1, float x2, float y2 ) {
+            drawLine( QLine( x1, y1, x2, y2 ) );
+        };
+        lambdaDrawCross = [this]( float centerX, float centerY, float sizeX, float sizeY ) {
+            drawLine( QLine( centerX - sizeX/2., centerY, centerX + sizeX/2., centerY ) );
+            drawLine( QLine( centerX, centerY - sizeY/2., centerX, centerY + sizeY/2. ) );
+        };
+    }
+
     switch ( type ) {
     case 0:
     case 1: //catalog star
         //Some NGC/IC objects are stars...changed their type to 1 (was double star)
         if (size<2.) size = 2.;
-        if ( Options::useAntialias() )
-            drawEllipse( QRectF(x1, y1, size/2., size/2.) );
-        else
-            drawEllipse( QRect(int(x1), int(y1), int(size/2), int(size/2)) );
+        lambdaDrawEllipse( x1, y1, size/2., size/2. );
         break;
     case 2: //Planet
         break;
     case 3: //Open cluster; draw circle of points
-    case 13: // Asterism
+    case 13: { // Asterism
         tempBrush = brush();
         color = pen().color().name();
         setBrush( pen().color() );
         psize = 2.;
         if ( size > 50. )  psize *= 2.;
         if ( size > 100. ) psize *= 2.;
-        if ( Options::useAntialias() ) {
-            drawEllipse( QRectF(xa, y1, psize, psize) );
-            drawEllipse( QRectF(xb, y1, psize, psize) );
-            drawEllipse( QRectF(xa, y2, psize, psize) );
-            drawEllipse( QRectF(xb, y2, psize, psize) );
-            drawEllipse( QRectF(x1, ya, psize, psize) );
-            drawEllipse( QRectF(x1, yb, psize, psize) );
-            drawEllipse( QRectF(x2, ya, psize, psize) );
-            drawEllipse( QRectF(x2, yb, psize, psize) );
-        } else {
-            int ix1 = int(x1); int iy1 = int(y1);
-            int ix2 = int(x2); int iy2 = int(y2);
-            int ixa = int(xa); int iya = int(ya);
-            int ixb = int(xb); int iyb = int(yb);
-            drawEllipse( QRect(ixa, iy1, int(psize), int(psize)) );
-            drawEllipse( QRect(ixb, iy1, int(psize), int(psize)) );
-            drawEllipse( QRect(ixa, iy2, int(psize), int(psize)) );
-            drawEllipse( QRect(ixb, iy2, int(psize), int(psize)) );
-            drawEllipse( QRect(ix1, iya, int(psize), int(psize)) );
-            drawEllipse( QRect(ix1, iyb, int(psize), int(psize)) );
-            drawEllipse( QRect(ix2, iya, int(psize), int(psize)) );
-            drawEllipse( QRect(ix2, iyb, int(psize), int(psize)) );
-        }
+        auto putDot = [this, psize, &lambdaDrawEllipse]( float x, float y ) {
+            lambdaDrawEllipse( x, y, psize, psize );
+        };
+        putDot( xa, y1 );
+        putDot( xb, y1 );
+        putDot( xa, y2 );
+        putDot( xb, y2 );
+        putDot( x1, ya );
+        putDot( x1, yb );
+        putDot( x2, ya );
+        putDot( x2, yb );
         setBrush( tempBrush );
         break;
+    }
     case 4: //Globular Cluster
         if (size<2.) size = 2.;
         save();
         translate( x, y );
         color = pen().color().name();
         rotate( positionAngle );  //rotate the coordinate system
-
-        if ( Options::useAntialias() ) {
-            drawEllipse( QRectF(dx1, dy1, size, e*size) );
-            drawLine( QPointF(0., dy1), QPointF(0., dy2) );
-            drawLine( QPointF(dx1, 0.), QPointF(dx2, 0.) );
-            restore(); //reset coordinate system
-        } else {
-            int idx1 = int(dx1); int idy1 = int(dy1);
-            int idx2 = int(dx2); int idy2 = int(dy2);
-            drawEllipse( QRect(idx1, idy1, isize, int(e*size)) );
-            drawLine( QPoint(0, idy1), QPoint(0, idy2) );
-            drawLine( QPoint(idx1, 0), QPoint(idx2, 0) );
-            restore(); //reset coordinate system
-        }
+        lambdaDrawEllipse( dx1, dy1, size, e*size );
+        lambdaDrawCross( 0, 0, size, e*size );
+        restore(); //reset coordinate system
         break;
 
     case 5: //Gaseous Nebula
@@ -630,20 +633,11 @@ void SkyQPainter::drawDeepSkySymbol(const QPointF &pos, int type, float size, fl
         save();
         translate( x, y );
         rotate( positionAngle );  //rotate the coordinate system
-color = pen().color().name();
-        if ( Options::useAntialias() ) {
-            drawLine( QPointF(dx1, dy1), QPointF(dx2, dy1) );
-            drawLine( QPointF(dx2, dy1), QPointF(dx2, dy2) );
-            drawLine( QPointF(dx2, dy2), QPointF(dx1, dy2) );
-            drawLine( QPointF(dx1, dy2), QPointF(dx1, dy1) );
-        } else {
-            int idx1 = int(dx1); int idy1 = int(dy1);
-            int idx2 = int(dx2); int idy2 = int(dy2);
-            drawLine( QPoint(idx1, idy1), QPoint(idx2, idy1) );
-            drawLine( QPoint(idx2, idy1), QPoint(idx2, idy2) );
-            drawLine( QPoint(idx2, idy2), QPoint(idx1, idy2) );
-            drawLine( QPoint(idx1, idy2), QPoint(idx1, idy1) );
-        }
+        color = pen().color().name();
+        lambdaDrawLine( dx1, dy1, dx2, dy1 );
+        lambdaDrawLine( dx2, dy1, dx2, dy2 );
+        lambdaDrawLine( dx2, dy2, dx1, dy2 );
+        lambdaDrawLine( dx1, dy2, dx1, dy1 );
         restore(); //reset coordinate system
         break;
     case 6: //Planetary Nebula
@@ -651,45 +645,24 @@ color = pen().color().name();
         save();
         translate( x, y );
         rotate( positionAngle );  //rotate the coordinate system
-color = pen().color().name();
-        if ( Options::useAntialias() ) {
-            drawEllipse( QRectF(dx1, dy1, size, e*size) );
-            drawLine( QPointF(0., dy1), QPointF(0., dy1 - e*size/2. ) );
-            drawLine( QPointF(0., dy2), QPointF(0., dy2 + e*size/2. ) );
-            drawLine( QPointF(dx1, 0.), QPointF(dx1 - size/2., 0.) );
-            drawLine( QPointF(dx2, 0.), QPointF(dx2 + size/2., 0.) );
-        } else {
-            int idx1 = int(dx1); int idy1 = int(dy1);
-            int idx2 = int(dx2); int idy2 = int(dy2);
-            drawEllipse( QRect( idx1, idy1, isize, int(e*size) ) );
-            drawLine( QPoint(0, idy1), QPoint(0, idy1 - int(e*size/2) ) );
-            drawLine( QPoint(0, idy2), QPoint(0, idy2 + int(e*size/2) ) );
-            drawLine( QPoint(idx1, 0), QPoint(idx1 - int(size/2), 0) );
-            drawLine( QPoint(idx2, 0), QPoint(idx2 + int(size/2), 0) );
-        }
-
+        color = pen().color().name();
+        lambdaDrawEllipse( dx1, dy1, size, e*size );
+        lambdaDrawLine( 0., dy1, 0., dy1 - e*size/2. );
+        lambdaDrawLine( 0., dy2, 0., dy2 + e*size/2. );
+        lambdaDrawLine( dx1, 0., dx1 - size/2., 0. );
+        lambdaDrawLine( dx2, 0., dx2 + size/2., 0. );
         restore(); //reset coordinate system
         break;
-    case 7: //Supernova remnant
+    case 7: //Supernova remnant // FIXME: Why is SNR drawn different from a gaseous nebula?
         if (size<2) size = 2;
         save();
         translate( x, y );
         rotate( positionAngle );  //rotate the coordinate system
-color = pen().color().name();
-        if ( Options::useAntialias() ) {
-            drawLine( QPointF(0., dy1), QPointF(dx2, 0.) );
-            drawLine( QPointF(dx2, 0.), QPointF(0., dy2) );
-            drawLine( QPointF(0., dy2), QPointF(dx1, 0.) );
-            drawLine( QPointF(dx1, 0.), QPointF(0., dy1) );
-        } else {
-            int idx1 = int(dx1); int idy1 = int(dy1);
-            int idx2 = int(dx2); int idy2 = int(dy2);
-            drawLine( QPoint(0, idy1), QPoint(idx2, 0) );
-            drawLine( QPoint(idx2, 0), QPoint(0, idy2) );
-            drawLine( QPoint(0, idy2), QPoint(idx1, 0) );
-            drawLine( QPoint(idx1, 0), QPoint(0, idy1) );
-        }
-
+        color = pen().color().name();
+        lambdaDrawLine( 0., dy1, dx2, 0. );
+        lambdaDrawLine( dx2, 0., 0., dy2 );
+        lambdaDrawLine( 0., dy2, dx1, 0. );
+        lambdaDrawLine( dx1, 0., 0., dy1 );
         restore(); //reset coordinate system
         break;
     case 8: //Galaxy
@@ -701,68 +674,60 @@ color = pen().color().name();
             save();
             translate( x, y );
             rotate( positionAngle );  //rotate the coordinate system
-
-            if ( Options::useAntialias() ) {
-                drawEllipse( QRectF(dx1, dy1, size, e*size) );
-            } else {
-                int idx1 = int(dx1); int idy1 = int(dy1);
-                drawEllipse( QRect(idx1, idy1, isize, int(e*size)) );
-            }
-
+            lambdaDrawEllipse( dx1, dy1, size, e*size );
             restore(); //reset coordinate system
 
         } else if ( size>0. ) {
             drawPoint( QPointF(x, y) );
         }
         break;
-    case 14: // Galaxy cluster - draw a circle of + marks
+    case 14: { // Galaxy cluster - draw a dashed circle
         tempBrush = brush();
-        setBrush( pen().color() );
+        setBrush( QBrush() );
         psize = 1.;
         if ( size > 50. )  psize *= 2.;
-color = pen().color().name();
-        if ( Options::useAntialias() ) {
-            drawLine( QLineF( xa - psize, y1, xa + psize, y1 ) );
-            drawLine( QLineF( xa, y1 - psize, xa, y1 + psize ) );
-            drawLine( QLineF( xb - psize, y1, xb + psize, y1 ) );
-            drawLine( QLineF( xb, y1 - psize, xb, y1 + psize ) );
-            drawLine( QLineF( xa - psize, y2, xa + psize, y2 ) );
-            drawLine( QLineF( xa, y2 - psize, xa, y2 + psize ) );
-            drawLine( QLineF( xb - psize, y2, xb + psize, y2 ) );
-            drawLine( QLineF( xb, y2 - psize, xb, y2 + psize ) );
-            drawLine( QLineF( x1 - psize, ya, x1 + psize, ya ) );
-            drawLine( QLineF( x1, ya - psize, x1, ya + psize ) );
-            drawLine( QLineF( x1 - psize, yb, x1 + psize, yb ) );
-            drawLine( QLineF( x1, yb - psize, x1, yb + psize ) );
-            drawLine( QLineF( x2 - psize, ya, x2 + psize, ya ) );
-            drawLine( QLineF( x2, ya - psize, x2, ya + psize ) );
-            drawLine( QLineF( x2 - psize, yb, x2 + psize, yb ) );
-            drawLine( QLineF( x2, yb - psize, x2, yb + psize ) );
-        } else {
-            int ix1 = int(x1); int iy1 = int(y1);
-            int ix2 = int(x2); int iy2 = int(y2);
-            int ixa = int(xa); int iya = int(ya);
-            int ixb = int(xb); int iyb = int(yb);
-            drawLine( QLineF( ixa - int(psize), iy1, ixa + int(psize), iy1 ) );
-            drawLine( QLineF( ixa, iy1 - int(psize), ixa, iy1 + int(psize) ) );
-            drawLine( QLineF( ixb - int(psize), iy1, ixb + int(psize), iy1 ) );
-            drawLine( QLineF( ixb, iy1 - int(psize), ixb, iy1 + int(psize) ) );
-            drawLine( QLineF( ixa - int(psize), iy2, ixa + int(psize), iy2 ) );
-            drawLine( QLineF( ixa, iy2 - int(psize), ixa, iy2 + int(psize) ) );
-            drawLine( QLineF( ixb - int(psize), iy2, ixb + int(psize), iy2 ) );
-            drawLine( QLineF( ixb, iy2 - int(psize), ixb, iy2 + int(psize) ) );
-            drawLine( QLineF( ix1 - int(psize), iya, ix1 + int(psize), iya ) );
-            drawLine( QLineF( ix1, iya - int(psize), ix1, iya + int(psize) ) );
-            drawLine( QLineF( ix1 - int(psize), iyb, ix1 + int(psize), iyb ) );
-            drawLine( QLineF( ix1, iyb - int(psize), ix1, iyb + int(psize) ) );
-            drawLine( QLineF( ix2 - int(psize), iya, ix2 + int(psize), iya ) );
-            drawLine( QLineF( ix2, iya - int(psize), ix2, iya + int(psize) ) );
-            drawLine( QLineF( ix2 - int(psize), iyb, ix2 + int(psize), iyb ) );
-            drawLine( QLineF( ix2, iyb - int(psize), ix2, iyb + int(psize) ) );
-        }
+        color = pen().color().name();
+        save();
+        translate( x, y );
+        rotate( positionAngle );  //rotate the coordinate system
+        QPen newPen = pen();
+        newPen.setStyle( Qt::DashLine );
+        setPen( newPen );
+        lambdaDrawEllipse( dx1, dy1, size, e*size );
+        restore();
         setBrush( tempBrush );
         break;
     }
+    default: // Unknown object or something we don't know how to draw. Just draw an ellipse with a ?-mark
+        color = pen().color().name();
+        if ( size <1. && zoom > 20*MINZOOM ) size = 3.; //force ellipse above zoomFactor 20
+        if ( size <1. && zoom > 5*MINZOOM ) size = 1.; //force points above zoomFactor 5
+        if ( size>2. ) {
+            save();
+            QFont f = font();
+            const QString qMark = " ? ";
+            double scaleFactor = 0.8 * size / fontMetrics().width( qMark );
+            f.setPointSizeF( f.pointSizeF() * scaleFactor );
+            setFont( f );
+            translate( x, y );
+            rotate( positionAngle );  //rotate the coordinate system
+            lambdaDrawEllipse( dx1, dy1, size, e*size );
+            if ( Options::useAntialias() )
+                drawText( QRectF(dx1, dy1, size, e*size), Qt::AlignCenter, qMark );
+            else {
+                int idx1 = int(dx1); int idy1 = int(dy1);
+                drawText( QRect(idx1, idy1, isize, int(e*size)), Qt::AlignCenter, qMark );
+            }
+            restore(); //reset coordinate system (and font?)
+        }
+        else if ( size>0. ) {
+            if ( Options::useAntialias() )
+                drawPoint( QPointF(x, y) );
+            else
+                drawPoint( QPoint( x, y ) );
+        }
+    }
+
 }
 
 void SkyQPainter::drawObservingList(const QList< SkyObject* >& obs)
@@ -875,4 +840,3 @@ bool SkyQPainter::drawSupernova(Supernova* sup)
     drawLine ( QPoint( pos.x (), pos.y() - 2.0 ), QPoint( pos.x(), pos.y() + 2.0 ) );
     return true;
 }
-
